==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ko.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "이 서버에서 서버간 공유를 사용할 수 없음",
    "The mountpoint name contains invalid characters." : "마운트 지점 이름에 잘못된 글자가 포함되어 있습니다.",
    "Invalid or untrusted SSL certificate" : "잘못되었거나 신뢰할 수 없는 SSL 인증서",
    "Could not authenticate to remote share, password might be wrong" : "원격 공유에서 인증할 수 없습니다. 암호가 맞지 않을 수 있습니다.",
    "Storage not valid" : "저장소가 잘못됨",
    "Couldn't add remote share" : "원격 공유를 추가할 수 없음",
    "Shared with you" : "나와 공유됨",
    "Shared with others" : "다른 사람과 공유됨",
    "Shared by link" : "링크로 공유됨",
    "Nothing shared with you yet" : "나와 공유된 항목 없음",
    "Files and folders others share with you will show up here" : "다른 사람이 공유한 파일과 폴더가 여기에 나타납니다",
    "Nothing shared yet" : "공유된 항목 없음",
    "Files and folders you share will show up here" : "내가 공유하는 파일과 폴더가 여기에 나타납니다",
    "No shared links" : "공유된 링크 없음",
    "Files and folders you share by link will show up here" : "내가 링크로 공유하는 파일과 폴더가 여기에 나타납니다",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}의 원격 공유 {name}을(를) 추가하시겠습니까?",
    "Remote share" : "원격 공유",
    "Remote share password" : "원격 공유 암호",
    "Cancel" : "취소",
    "Add remote share" : "원격 공유 추가",
    "You can upload into this folder" : "이 폴더에 업로드할 수 있습니다",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote}에 ownCloud 7 이상이 설치되어 있지 않음",
    "Invalid ownCloud url" : "잘못된 ownCloud URL",
    "Shared by" : "공유한 사용자:",
    "Sharing" : "공유",
    "A file or folder has been <strong>shared</strong>" : "파일이나 폴더가 <strong>공유됨</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>다른 서버</strong>에서 파일이나 폴더를 공유함",
    "A public shared file or folder was <strong>downloaded</strong>" : "공개 공유된 파일이나 폴더가 <strong>다운로드됨</strong>",
    "You received a new remote share %2$s from %1$s" : "%1$s에서 새 원격 공유 %2$s을(를) 받았습니다",
    "You received a new remote share from %s" : "%s에서 원격 공유 요청을 받았습니다",
    "%1$s accepted remote share %2$s" : "%1$s 님이 원격 공유 %2$s을(를) 수락함",
    "%1$s declined remote share %2$s" : "%1$s 님이 원격 공유 %2$s을(를) 거절함",
    "%1$s unshared %2$s from you" : "%1$s 님이 %2$s의 공유를 중단함",
    "Public shared folder %1$s was downloaded" : "공개 공유 폴더 %1$s이(가) 다운로드됨",
    "Public shared file %1$s was downloaded" : "공개 공유 파일 %1$s이(가) 다운로드됨",
    "You shared %1$s with %2$s" : "내가 %2$s 님과 %1$s을(를) 공유함",
    "%2$s shared %1$s with %3$s" : "%2$s 님이 %1$s을(를) %3$s 님과 공유함",
    "You shared %1$s with group %2$s" : "내가 %2$s 그룹과 %1$s을(를) 공유함",
    "%2$s shared %1$s with group %3$s" : "%2$s 님이 %1$s을(를) %3$s 그룹과 공유함",
    "%2$s shared %1$s via link" : "%2$s 님이 %1$s을(를) 링크로 공유함",
    "You shared %1$s via link" : "내가 %1$s을(를) 링크로 공유함",
    "%2$s shared %1$s with you" : "%2$s 님이 내게 %1$s을(를) 공유함",
    "Downloaded via public link" : "공개 링크로 다운로드",
    "Shared with %2$s" : "%2$s 님과 공유함",
    "Shared with %3$s by %2$s" : "%2$s 님이 %3$s 님과 공유함",
    "Shared with group %2$s" : "%2$s 그룹과 공유함",
    "Shared with group %3$s by %2$s" : "%2$s 님이 %3$s 그룹과 공유함",
    "Shared via link by %2$s" : "%2$s 님이 링크로 공유함",
    "Shared via public link" : "공개 링크로 공유함",
    "Shared by %2$s" : "%2$s 님이 공유함",
    "Shares" : "공유",
    "Accept" : "수락",
    "Decline" : "거절",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "내 #ownCloud 연합 클라우드 ID를 통해서 공유됨, 더 알아보기: %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "내 #ownCloud 연합 클라우드 ID를 통해서 공유됨",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 입력해 주십시오.",
    "Password" : "암호",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Name" : "이름",
    "Share time" : "공유 시간",
    "Sorry, this link doesn’t seem to work anymore." : "죄송합니다. 이 링크는 더 이상 작동하지 않습니다.",
    "Reasons might be:" : "이유는 다음과 같을 수 있습니다:",
    "the item was removed" : "항목이 삭제됨",
    "the link expired" : "링크가 만료됨",
    "sharing is disabled" : "공유가 비활성화됨",
    "For more info, please ask the person who sent this link." : "자세한 정보는 링크를 보낸 사람에게 문의하십시오.",
    "Add to your ownCloud" : "내 ownCloud에 추가하기",
    "Download" : "다운로드",
    "Download %s" : "%s 다운로드",
    "Direct link" : "직접 링크",
    "Federated Cloud Sharing" : "클라우드 연합 공유",
    "Open documentation" : "문서 열기",
    "Allow users on this server to send shares to other servers" : "이 서버의 사용자가 다른 서버와 공유할 수 있도록 허용",
    "Allow users on this server to receive shares from other servers" : "이 서버의 사용자가 다른 서버에서 공유한 파일을 받을 수 있도록 허용",
    "Federated Cloud" : "연합 클라우드",
    "Your Federated Cloud ID:" : "내 연합 클라우드 ID:",
    "Share it:" : "공유하기:",
    "Add to your website" : "내 웹 사이트에 추가",
    "Share with me via ownCloud" : "ownCloud로 나와 공유하기",
    "HTML Code:" : "HTML 코드:",
    "Federated sharing" : "연합 공유",
    "Not allowed to create a federated share with the same user server" : "같은 사용자 서버 내에서 연합 공유를 만들 수 없음",
    "Public link expired" : "공개 링크 만료됨",
    "Public link of %2$s expired" : "%2$s 님의 공개 링크 만료됨",
    "Public shared file %1$s was downloaded" : "공개 공유 파일 %1$s이(가) 다운로드됨",
    "Public shared folder %1$s was downloaded" : "공개 공유 폴더 %1$s이(가) 다운로드됨",
    "Removed public link" : "공개 링크 삭제함",
    "Removed share for %2$s" : "%2$s 님의 공유를 삭제함",
    "Removed share of group %2$s" : "%2$s 그룹의 공유를 삭제함",
    "Shared by %2$s" : "%2$s 님이 공유함",
    "Shared via link by %2$s" : "%2$s 님이 링크로 공유함",
    "Shared with group %3$s by %2$s" : "%2$s 님이 %3$s 그룹과 공유함",
    "The public link of %2$s for %1$s expired" : "%2$s 님의 %1$s 공개 링크가 만료됨",
    "You removed the public link for %1$s" : "%1$s의 공개 링크를 삭제함",
    "You removed the share of %2$s for %1$s" : "%1$s을(를) 위한 %2$s 그룹의 공유를 삭제함",
    "You removed the share of group %2$s for %1$s" : "%1$s 님을 위한 %2$s 그룹 공유를 삭제함",
    "Your public link for %1$s expired" : "%1$s의 공개 링크가 만료됨"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ko.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "이 서버에서 서버간 공유를 사용할 수 없음",
    "The mountpoint name contains invalid characters." : "마운트 지점 이름에 잘못된 글자가 포함되어 있습니다.",
    "Not allowed to create a federated share with the same user server" : "같은 사용자 서버 내에서 연합 공유를 만들 수 없음",
    "Invalid or untrusted SSL certificate" : "잘못되었거나 신뢰할 수 없는 SSL 인증서",
    "Could not authenticate to remote share, password might be wrong" : "원격 공유에서 인증할 수 없습니다. 암호가 맞지 않을 수 있습니다.",
    "Storage not valid" : "저장소가 잘못됨",
    "Couldn't add remote share" : "원격 공유를 추가할 수 없음",
    "Shared with you" : "나와 공유됨",
    "Shared with others" : "다른 사람과 공유됨",
    "Shared by link" : "링크로 공유됨",
    "Nothing shared with you yet" : "나와 공유된 항목 없음",
    "Files and folders others share with you will show up here" : "다른 사람이 공유한 파일과 폴더가 여기에 나타납니다",
    "Nothing shared yet" : "공유된 항목 없음",
    "Files and folders you share will show up here" : "내가 공유하는 파일과 폴더가 여기에 나타납니다",
    "No shared links" : "공유된 링크 없음",
    "Files and folders you share by link will show up here" : "내가 링크로 공유하는 파일과 폴더가 여기에 나타납니다",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}의 원격 공유 {name}을(를) 추가하시겠습니까?",
    "Remote share" : "원격 공유",
    "Remote share password" : "원격 공유 암호",
    "Cancel" : "취소",
    "Add remote share" : "원격 공유 추가",
    "You can upload into this folder" : "이 폴더에 업로드할 수 있습니다",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote}에 ownCloud 7 이상이 설치되어 있지 않음",
    "Invalid ownCloud url" : "잘못된 ownCloud URL",
    "Shared by" : "공유한 사용자:",
    "Sharing" : "공유",
    "A file or folder has been <strong>shared</strong>" : "파일이나 폴더가 <strong>공유됨</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>다른 서버</strong>에서 파일이나 폴더를 공유함",
    "A public shared file or folder was <strong>downloaded</strong>" : "공개 공유된 파일이나 폴더가 <strong>다운로드됨</strong>",
    "You received a new remote share %2$s from %1$s" : "%1$s에서 새 원격 공유 %2$s을(를) 받았습니다",
    "You received a new remote share from %s" : "%s에서 원격 공유 요청을 받았습니다",
    "%1$s accepted remote share %2$s" : "%1$s 님이 원격 공유 %2$s을(를) 수락함",
    "%1$s declined remote share %2$s" : "%1$s 님이 원격 공유 %2$s을(를) 거절함",
    "%1$s unshared %2$s from you" : "%1$s 님이 %2$s의 공유를 중단함",
    "Public shared folder %1$s was downloaded" : "공개 공유 폴더 %1$s이(가) 다운로드됨",
    "Public shared file %1$s was downloaded" : "공개 공유 파일 %1$s이(가) 다운로드됨",
    "You shared %1$s with %2$s" : "내가 %2$s 님과 %1$s을(를) 공유함",
    "%2$s shared %1$s with %3$s" : "%2$s 님이 %1$s을(를) %3$s 님과 공유함",
    "You removed the share of %2$s for %1$s" : "%1$s을(를) 위한 %2$s 그룹의 공유를 삭제함",
    "%2$s removed the share of %3$s for %1$s" : "%2$s 님이 %1$s을(를) 위한 %3$s 그룹의 공유를 삭제함",
    "You shared %1$s with group %2$s" : "내가 %2$s 그룹과 %1$s을(를) 공유함",
    "%2$s shared %1$s with group %3$s" : "%2$s 님이 %1$s을(를) %3$s 그룹과 공유함",
    "You removed the share of group %2$s for %1$s" : "%1$s 님을 위한 %2$s 그룹 공유를 삭제함",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s 님이 %1$s에 대한 %3$s 그룹의 공유를 삭제함",
    "%2$s shared %1$s via link" : "%2$s 님이 %1$s을(를) 링크로 공유함",
    "You shared %1$s via link" : "내가 %1$s을(를) 링크로 공유함",
    "You removed the public link for %1$s" : "%1$s의 공개 링크를 삭제함",
    "%2$s removed the public link for %1$s" : "%2$s 님이 %1$s의 공개 링크를 삭제함",
    "Your public link for %1$s expired" : "%1$s의 공개 링크가 만료됨",
    "The public link of %2$s for %1$s expired" : "%2$s 님의 %1$s 공개 링크가 만료됨",
    "%2$s shared %1$s with you" : "%2$s 님이 내게 %1$s을(를) 공유함",
    "%2$s removed the share for %1$s" : "%2$s 님이 %1$s 공유를 삭제함",
    "Downloaded via public link" : "공개 링크로 다운로드",
    "Shared with %2$s" : "%2$s 님과 공유함",
    "Shared with %3$s by %2$s" : "%2$s 님이 %3$s 님과 공유함",
    "Removed share for %2$s" : "%2$s 님의 공유를 삭제함",
    "%2$s removed share for %3$s" : "%2$s 님이 %3$s 님의 공유를 삭제함",
    "Shared with group %2$s" : "%2$s 그룹과 공유함",
    "Shared with group %3$s by %2$s" : "%2$s 님이 %3$s 그룹과 공유함",
    "Removed share of group %2$s" : "%2$s 그룹의 공유를 삭제함",
    "%2$s removed share of group %3$s" : "%2$s 님이 그룹 %3$s의 공유를 삭제함",
    "Shared via link by %2$s" : "%2$s 님이 링크로 공유함",
    "Shared via public link" : "공개 링크로 공유함",
    "Removed public link" : "공개 링크 삭제함",
    "%2$s removed public link" : "%2$s 님이 공개 링크 삭제함",
    "Public link expired" : "공개 링크 만료됨",
    "Public link of %2$s expired" : "%2$s 님의 공개 링크 만료됨",
    "Shared by %2$s" : "%2$s 님이 공유함",
    "Shares" : "공유",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 입력해 주십시오.",
    "Password" : "암호",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Name" : "이름",
    "Share time" : "공유 시간",
    "Sorry, this link doesn’t seem to work anymore." : "죄송합니다. 이 링크는 더 이상 작동하지 않습니다.",
    "Reasons might be:" : "이유는 다음과 같을 수 있습니다:",
    "the item was removed" : "항목이 삭제됨",
    "the link expired" : "링크가 만료됨",
    "sharing is disabled" : "공유가 비활성화됨",
    "For more info, please ask the person who sent this link." : "자세한 정보는 링크를 보낸 사람에게 문의하십시오.",
    "Add to your ownCloud" : "내 ownCloud에 추가하기",
    "Download" : "다운로드",
    "Download %s" : "%s 다운로드",
    "Direct link" : "직접 링크"
},
"nplurals=1; plural=0;");
